#!/bin/sh

CURRENT_VERSION_INFO=`readelf -p versection /var/varian/4900app.exe  |grep 0] | awk {'print $3'}`
CURRENT_BUILD_NR_STR=`readelf -p buildnrsection /var/varian/4900app.exe  |grep 0] | awk {'print $3'}`
CURRENT_BUILD_NR=`readelf -p buildnrsection /var/varian/4900app.exe  |grep 0] | awk '{value=$3; printf("%d",value)}'`

### 
# Starting from build firmware build number 26866 webupdates are allowed.
###
if [ $CURRENT_BUILD_NR -lt 26866 ]; then
    logger -t Update stopped due to old rootfs. Current build number is "$CURRENT_BUILD_NR_STR", minimum build number is 26866. Please update via SD card.
    echo Update stopped due to old rootfs. Current build number is "$CURRENT_BUILD_NR_STR", minimum build number is 26866. Please update via SD card. >> /var/varian/ERRORLOG.TXT
    exit 1
fi 

###
# Log start of firmware update in syslog and ERRORLOG
###
logger -t Start firmware update
logger -t Current version: "$CURRENT_VERSION_INFO" build "$CURRENT_BUILD_NR_STR"
echo Start firmware update >> /var/varian/ERRORLOG.TXT
echo Current version: "$CURRENT_VERSION_INFO" build "$CURRENT_BUILD_NR_STR" >> /var/varian/ERRORLOG.TXT


###
# Script to unpack the appVersion###Build#####.tgz 
# remove/replace files in /bin/varian and /var/varian
# Script is executed on MicroGC by webupdate script.
# On MicroGC the location of this script and the .tgz file is in a temperory directory 'update'
#
# only empty /bin/varian; /var/varian also contains persistance files
rm -rf /bin/varian

FILES=`find . -type f -name "*.tgz" 2> /dev/null`
if [ ! -z "$FILES" ]; then
	for FILE in $FILES; do
        tar --no-same-owner -C / -xzf "$FILE"
	done
	sync
fi

### 
# Dump version info of new firmware
###
VERSION_INFO=`readelf -p versection /var/varian/4900app.exe  |grep 0] | awk {'print $3'}`
BUILD_INFO=`readelf -p buildnrsection /var/varian/4900app.exe  |grep 0] | awk {'print $3'}`

logger -t Updated to version: "$VERSION_INFO" build "$BUILD_INFO"
echo Updated to version: "$VERSION_INFO" build "$BUILD_INFO" >> /var/varian/ERRORLOG.TXT

mkdir -p /var/versions
echo "$VERSION_INFO""$BUILD_INFO" > /var/versions/4900app.exe

logger -t Finished updating GC
echo Finished updating GC >> /var/varian/ERRORLOG.TXT

sync
